@@ -119,6 +119,7 @@ type token =
   | TMetaErr of (Parse_aux.expinfo)
   | TMetaDeclarer of (Parse_aux.idinfo)
   | TMetaDecl of (Parse_aux.info)
+  | TMetaDParamList of (Parse_aux.list_info)
   | TMetaConst of (Parse_aux.typed_expinfo)
   | TMetaBinaryOp of (Parse_aux.binaryOpinfo)
   | TMetaAssignOp of (Parse_aux.assignOpinfo)
@@ -144,7 +145,9 @@ type token =
   | TInitialiser
   | TIncludeNL of (string * Data.clt)
   | TIncludeL of (string * Data.clt)
+  | TIncludeAny of (string * Data.clt)
   | TInc of (Data.clt)
+  | TIn
   | TIf of (Data.clt)
   | TIdentifier
   | TIdent of (string * Data.clt)
@@ -160,6 +163,7 @@ type token =
   | TFor of (Data.clt)
   | TFloat of (string * Data.clt)
   | TFinalize
+  | TFile
   | TField
   | TExtends
   | TExpression
@@ -185,6 +189,7 @@ type token =
   | TDeclaration
   | TDecimalCst of (string * string (*n*) * string (*p*) * Data.clt)
   | TDec of (Data.clt)
+  | TCppEscapedNewline of (Data.clt)
   | TCppConcatOp
   | TContinue of (Data.clt)
   | TContext
